@@ -7,7 +7,9 @@ from openpyxl import Workbook
 from rumydata.field import Integer, Field, Text
 from rumydata.rules.column import Unique
 from rumydata.table import Layout, CsvFile, ExcelFile, _BaseFile
+from rumydata import exception as ex
 from tests.utils import mock_no_module
+from rumydata import rules
 
 
 @pytest.fixture
@@ -138,11 +140,20 @@ def test_excel_cell_format():
 def test_no_header_true_bad(tmpdir):
     hid = uuid4().hex[:5]
     p = Path(tmpdir, hid)
-    p.write_text('\n'.join(['aaaa,b', 'c,d']))
+    p.write_text('\n'.join(['aa,b', 'c,d']))
     layout = Layout({'c1': Text(1), 'c2': Text(1)}, no_header=True)
     assert False if CsvFile(layout)._list_errors(p) == [None] else True
 
 
+def test_no_header_true_bad_plus(tmpdir):
+    hid = uuid4().hex[:5]
+    p = Path(tmpdir, hid)
+    p.write_text('\n'.join(['aa,b', 'cc,d']))
+    layout = Layout({'c1': Text(1), 'c2': Text(1)}, no_header=True)
+    errors = CsvFile(layout)._list_errors(p)
+    assert True if len([x for x in errors if type(x) == ex.RowError]) == 2 else False
+
+
 def test_no_header_true_good(tmpdir):
     hid = uuid4().hex[:5]
     p = Path(tmpdir, hid)
@@ -181,3 +192,70 @@ def test_no_header_default_bad(tmpdir):
     p.write_text('\n'.join(['a,b', 'c,d']))
     layout = Layout({'c1': Text(1), 'c2': Text(1)})
     assert False if CsvFile(layout)._list_errors(p) == [None] else True
+
+
+def test_no_header_with_column_rule(tmpdir):
+    hid = uuid4().hex[:5]
+    p = Path(tmpdir, hid)
+    p.write_text('\n'.join(['a', 'a']))
+    layout = Layout({'c1': Text(1, rules=[Unique()])}, no_header=True)
+    assert True if CsvFile(layout)._has_error(p, Unique.rule_exception()) else False
+
+
+def test_no_header_with_skip_rows(tmpdir):
+    hid = uuid4().hex[:5]
+    p = Path(tmpdir, hid)
+    p.write_text('\n'.join(['aa', 'aa', 'aa']))
+    layout = Layout({'c1': Text(1, rules=[Unique()])}, no_header=True)
+    errors = CsvFile(layout, skip_rows=1)._list_errors(p)
+    assert True if all([len([x for x in errors if type(x) == ex.ColumnError]) == 1,
+                        len([x for x in errors if type(x) == ex.RowError]) == 2]) else False
+
+
+def test_skip_rows_bad_header(tmpdir):
+    hid = uuid4().hex[:5]
+    p = Path(tmpdir, hid)
+    p.write_text('\n'.join(['', 'c2', 'aa', 'aa']))
+    layout = Layout({'c1': Text(2, rules=[Unique()])})
+    csv = CsvFile(layout, skip_rows=1)
+    assert all(
+        [csv._has_error(p, rules.header.ColumnOrder.rule_exception()), not csv._has_error(p, Unique.rule_exception())])
+
+
+@pytest.mark.parametrize('skip, expected', [
+    (1, True),
+    (2, False)
+])
+def test_skip_rows_skips_columns_errors(tmpdir, skip, expected):
+    hid = uuid4().hex[:5]
+    p = Path(tmpdir, hid)
+    p.write_text('\n'.join(['a', 'a', 'a', 'a']))
+    layout = Layout({'a': Text(2, rules=[Unique()])})
+    csv = CsvFile(layout, skip_rows=skip)
+    assert csv._has_error(p, Unique.rule_exception()) is expected
+
+
+def test_ignore_if_single_good(tmpdir):
+    hid = uuid4().hex[:5]
+    p = Path(tmpdir, hid)
+    p.write_text('\n'.join(['c1,c2', 'x,', 'c,d']))
+    layout = Layout({'c1': Text(1), 'c2': Text(1)}, empty_row_ok=True)
+    results = CsvFile(layout, ignore_exceptions={'c1': 'x'}).check(p)
+    assert True if not results else False
+
+
+def test_ignore_if_single_bad(tmpdir):
+    hid = uuid4().hex[:5]
+    p = Path(tmpdir, hid)
+    p.write_text('\n'.join(['c1,c2', 'z,', 'c,d']))
+    layout = Layout({'c1': Text(1), 'c2': Text(1)}, empty_row_ok=True)
+    assert False if CsvFile(layout, ignore_exceptions={'c1': 'x'})._list_errors(p) == [None] else True
+
+
+def test_ignore_if_list(tmpdir):
+    hid = uuid4().hex[:5]
+    p = Path(tmpdir, hid)
+    p.write_text('\n'.join(['c1,c2', 'x,z', 'c,d', ',', 'z,', 'x,']))
+    layout = Layout({'c1': Text(1), 'c2': Text(1)}, empty_row_ok=True)
+    results = CsvFile(layout, ignore_exceptions={'c1': ['x', 'z']}).check(p)
+    assert True if not results else False
